summaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
Diffstat (limited to 'tests')
-rwxr-xr-xtests/travis/run.sh5
1 files changed, 3 insertions, 2 deletions
diff --git a/tests/travis/run.sh b/tests/travis/run.sh
index b014266..fae7a31 100755
--- a/tests/travis/run.sh
+++ b/tests/travis/run.sh
@@ -67,8 +67,9 @@ if test -n "$USESSL"; then
fi
fi
elif test -z "$USECURL"; then
- # default for ubuntu 12 which is what travis currently uses is openssl
- export PYCURL_SSL_LIBRARY=openssl
+ # default for ubuntu 12 is openssl
+ # default for ubuntu 14 which is what travis currently uses is gnutls
+ export PYCURL_SSL_LIBRARY=gnutls
fi
if test -n "$AVOIDSTDIO"; then